Installation
============

**pytest-copie** is available on `PyPI <https://pypi.org/project/pytest-copie/>`__ and can be installed with `pip <https://pip.pypa.io/en/stable/>`__:

.. code-block:: console

    pip install pytest-copie

Alternatively it is also available on `conda-forge <https://anaconda.org/conda-forge/pytest-copie>`__ and can be installed with `conda <https://docs.conda.io/en/latest/>`__:

.. code-block:: console

    conda install pytest-copie
